#
# spec file for package gnome-backgrounds
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-backgrounds
Version:        47.0
Release:        1.1
Summary:        GNOME Backgrounds
License:        CC-BY-SA-3.0
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/gnome-backgrounds
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  meson
BuildRequires:  pkgconfig
# jpeg-xl pixbuf loader
Requires:       gdk-pixbuf-loader-jxl
# svg pixbuf loader
Requires:       gdk-pixbuf-loader-rsvg
# webp pixbuf loader
Requires:       webp-pixbuf-loader
BuildArch:      noarch
Obsoletes:      %{name}-lang < %{version}

%description
Background images from the GNOME project.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS
%{_datadir}/gnome-background-properties/
%{_datadir}/backgrounds/

%changelog
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + build fix.
* Thu Aug 22 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + default: adjusted optics
  + lcd,lcd-rainbow: nostalgia pixels
  + map: geometric vectors
  + pills: shading improvements
  + sheet: curvy curtain
  + swoosh: classic gradients
  + symbolic-soup: noisier than usual
* Sat Apr 20 2024 Frogster <lilfrogg@posteo.net>
- Add requirement for gdk-pixbuf-loader-jxl to be able to show the
  Gnome 46 backgrounds
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + No changes since 46.beta.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + default: less lens distortion.
  + symbolics: updated icons & tweaks to the layout.
  + glass chip: improved compression.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + New default. Embrace the rounded triangle!
  + Updated Amber, Pills.
  + New additions -- Gometrics, Glass chip, Neogeo, Ring and Tarka.
  + Departures -- Keys, Truchet, Rounded Rectangles.
  + JPEG XL favored as a format, with banding-bustin' client side
    grain.
- Convert to source service for easier updating.
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + No changes from 45.rc, stable versionbump only.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.rc:
  + Revert to JPEGs
  + Blue default (light)
* Tue Jul 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + New default
  + Morphogenesis (reactive diffusion)
  + Pipes
  + Updated pixels & truchet
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Stable version bump only.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + New supplemental and default wallpapers.
* Wed Feb 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Version bump only.
* Mon Sep 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Set hard Requires for gdk-pixbuf-loader-rsvg and
  webp-pixbuf-loader, ensure they are install for everyone
  installing gnome-backgrounds (boo#1203716).
* Tue Sep 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Updated to version 43:
  + No changes, stable bump only.
* Tue Sep  6 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 43.rc:
  + Minor janitory.
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add rich Requires to pull in svg and webp pixbuf loaders.
  (gdk-pixbuf-loader-rsvg if libgdk_pixbuf-2_0) and
  (webp-pixbuf-loader if libgdk_pixbuf-2_0).
* Fri Aug  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + All new 43 set of default and supplemental wallpapers.
  + SVG and WebM formats for better compression and resolution.
  + 4k square format targeting both widescreen, 4:3 and portrait
    displays.
* Mon Mar 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Split xml files per background for easier cherry-picking by
    distros.
  + Clean up credentials.
- Update License following upstream changes.
* Wed Feb 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + New default & supplemental wallpapers in light and dark variants
  + Updated guidelines.
* Mon Sep 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.0:
  + New default & supplemental updates.
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Lower default resolution for saner memory footprint.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + No changes compared to version 40.rc.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + New default & supplemental updates.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + No changes.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.92.1:
  + new default & supplemental updates.
- Drop -lang package: there are no translations installed.
- Obsolete the -lang package to ease upgrades.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + New default & supplemental updates.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Updated translations.
* Thu Sep 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + New default & supplemental updates.
* Mon Mar 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + New default & supplemental updates.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + New defaults.
- Use autosetup macro.
* Wed Mar 14 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + No visible changes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb  9 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + New defaults.
  + New supplemental additions.
- Add CC-BY-2.0, CC-BY-SA-2.0 and CC-BY-SA-3.0 to the License tag
  so then complying with the pictures copyrights.
* Sat Sep 16 2017 zaitor@opensuse.org
- Update to version 3.26.2:
  + Include meson files in the tarball.
  + Make sure Signpost_of_the_Shadows.jpg gets installed.
- Drop fdupes BuildRequires and fdupes macro, no longer needed nor
  serves any purpose.
* Thu Sep 14 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Fix build issue.
- Changes from version 3.26.0:
  + Updated translations.
* Mon Jul 17 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Switch to meson buildsystem.
  + Drop intltool dependency, port to gettext.
  + Drop translation-update-upstream in spec since it becomes
    useless when the intltool dependency is removed (bgo#783223).
  + New 3.26 default background.
- Add meson and pkgconfig BuildRequires and switch autotools macros
  configure, make and makeinstall to meson, meson_build and
  meson_install following upstream switch to Meson build system.
- Drop intltool and glib2-devel BuildRequires, no longer needed.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Wed Feb  1 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Updated default wallpaper.
* Tue Oct  4 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Noise ('fireflies') removal on adwaita-day.
- Remove old and currently unneeded workaround for latin locale.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + New default background.
  + 2 new icelandic additions replacing old low res.
- Remove old conditional for obsolete versions of openSUSE.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon May  2 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20:
  + Updated translations.
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + New default background.
  + Replaced Whispey Tails with Iceland Waterfalls.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + New defaults for 3.18.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated translations.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Updated default Adwaita wallpaper.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Add missing licensing information (bgo#735803).
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Add default wallpaper (Adwaita).
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Updated lock screen background.
  + Updated translations.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + New lock screen background.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep  2 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Fix autogen and configure (bgo#706792).
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + No changes since version 3.7.92.
* Wed Mar 20 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Updated COPYING file (bgo#650910).
* Mon Jan 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.91:
  + Replace "Stamps" background with "Mirror" (bgo#683444).
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Refreshed set of wallpapers for 3.6
  + Hardcode colors for all backgrounds (bgo#675466)
  + Switch to xz compression for distribution
  + Updated translations.
* Sat Jul 21 2012 dimstar@opensuse.org
- Split out lang-package (bnc#645077).
- Recommend -lang package from the main package.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Updated translations.
* Mon Apr 16 2012 zaitor@opensuse.org
- Update to version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + Updated version of Sundown Dunes.
  + Updated translations.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Updated translations.
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add former default wallpaper
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Add translator comments to names of background images
    (bgo#646387).
  + Updated translations.
* Tue Jun 14 2011 vuntz@opensuse.org
- Update to version 3.1.2:
  + Updated translations.
* Mon May 23 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Wed Mar 30 2011 fcrozat@novell.com
- Remove dependency on gnome-themes, not needed.
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + New backgrounds
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Add individual copyright notices for the images (bgo#620892)
  + Use AM_SILENT_RULES (bgo#607180)
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Mar 23 2010 dimstar@opensuse.org
- Remove en@shaw locale on openSUSE <= 11.2.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Updated translations.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.91:
  + bgo#579059: the storm background is missing in the appearance
    dialogs
  + Updated translations.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.24.1:
  + Updated translations.
- Remove unneeded BuildRequires: gnome-themes, perl-XML-Parser
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Wed Oct  1 2008 mboman@suse.de
- Update to version 2.24.0:
  + Translation updates
* Fri Sep 12 2008 vuntz@novell.com
- Update to version 2.23.92:
  + Updated translations.
* Fri Sep  5 2008 maw@suse.de
- Rename that pesky sr@latin locale to sr@Latn.
* Mon Sep  1 2008 mboman@novell.com
- Update to version 2.23.91:
  + Updated translations.
* Fri Aug 29 2008 maw@suse.de
- Update to versino 2.23.90:
  + Tweaked and updated several backgrounds with transparent
    versions
  + Updated translations.
* Fri Aug  8 2008 maw@suse.de
- Update to version 2.23.0:
  + New backgrounds taken from a background contest.
* Fri May 16 2008 aj@suse.de
- Fix directory ownership.
- Remove extra BuildRequires.
* Tue Apr  1 2008 vuntz@suse.de
- Remove uz@cyrillic workaround (see bnc#372941)
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Updated translations.
* Tue Mar 11 2008 lrupp@suse.de
- disable the lc-messages directories for now: breaks build
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Wed Sep 19 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * updated translations
* Fri Aug  3 2007 maw@suse.de
- Update to version 2.18.3:
  + New and updated translations.
* Mon Jul 16 2007 lrupp@suse.de
- fix filelist and requires
- build as noarch package
* Thu Mar  8 2007 maw@suse.de
- Update to version 2.16.2.
  changes: updated translations for ar and pl
* Thu Jan 11 2007 sbrabec@suse.cz
- Spec file cleanup.
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.16.1
- translation updates
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.92
- translation updates
* Thu Aug 10 2006 jhargadon@suse.de
- update to version 2.14.2.1
- added translations
- Revised colours
- New default colours for translucent backgrounds
- added a new set of backgrounds
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
* Wed Nov 16 2005 sbrabec@suse.cz
- Use %%find_lang.
* Wed Oct 12 2005 gekker@suse.de
- Update to version 2.12.1
* Mon Sep  5 2005 gekker@suse.de
- Update to version 2.12.0 (GNOME 2.12)
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.11.92
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.10.2
* Fri Jun 17 2005 gekker@suse.de
- Update to version 2.10.1
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 2.9.92
* Thu Feb 10 2005 gekker@suse.de
- Update to version 2.9.91
* Sat Feb  5 2005 gekker@suse.de
- Update to version 2.9.90
* Thu Jan 20 2005 clahey@suse.de
- New package.
